==> fet-5.14.2.tar.bz2: fet-5.14.2/src/interface/modifyconstraintactivitiessamestartingtimeform.h <==
/***************************************************************************
                          modifyconstraintactivitiessamestartingtimeform.h  -  description
                             -------------------
    begin                : Feb 11, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTACTIVITIESSAMESTARTINGTIMEFORM_H
#define MODIFYCONSTRAINTACTIVITIESSAMESTARTINGTIMEFORM_H

#include "ui_modifyconstraintactivitiessamestartingtimeform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <QList>

class ModifyConstraintActivitiesSameStartingTimeForm : public QDialog, Ui::ModifyConstraintActivitiesSameStartingTimeForm_template  {
	Q_OBJECT
public:
	ModifyConstraintActivitiesSameStartingTimeForm(ConstraintActivitiesSameStartingTime* ctr);
	~ModifyConstraintActivitiesSameStartingTimeForm();

	//void updateActivitiesListBox();

	bool filterOk(Activity* ac);
	
public slots:
	void addActivity();
	void removeActivity();

	void clear();

	void ok();
	void cancel();
	
	void filterChanged();
	
private:
	ConstraintActivitiesSameStartingTime* _ctr;
	//the id's of the activities listed in the activities list
	QList<int> activitiesList;
	//the id-s of the activities listed in the list of selected activities
	QList<int> selectedActivitiesList;
};

#endif

==> fet_5.28.1.orig.tar.bz2: fet-5.28.1/src/interface/modifyconstraintactivitiessamestartingtimeform.h <==
/***************************************************************************
                          modifyconstraintactivitiessamestartingtimeform.h  -  description
                             -------------------
    begin                : Feb 11, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTACTIVITIESSAMESTARTINGTIMEFORM_H
#define MODIFYCONSTRAINTACTIVITIESSAMESTARTINGTIMEFORM_H

#include "ui_modifyconstraintactivitiessamestartingtimeform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <QList>

class ModifyConstraintActivitiesSameStartingTimeForm : public QDialog, Ui::ModifyConstraintActivitiesSameStartingTimeForm_template  {
	Q_OBJECT
public:
	ModifyConstraintActivitiesSameStartingTimeForm(QWidget* parent, ConstraintActivitiesSameStartingTime* ctr);
	~ModifyConstraintActivitiesSameStartingTimeForm();

	bool filterOk(Activity* ac);
	
public slots:
	void addActivity();
	void addAllActivities();
	void removeActivity();

	void clear();

	void ok();
	void cancel();
	
	void filterChanged();
	
private:
	ConstraintActivitiesSameStartingTime* _ctr;
	//the id's of the activities listed in the activities list
	QList<int> activitiesList;
	//the id-s of the activities listed in the list of selected activities
	QList<int> selectedActivitiesList;
};

#endif
